skhubness.reduction API — scikit-hubness 0.21a1 documentation

# skhubness.reduction API

## skhubness.reduction Package

The `skhubness.reduction` package provides methods for hubness reduction.

class `skhubness.reduction.` `NoHubnessReduction`

  Dummy class to test the library

class `skhubness.reduction.` `LocalScaling`(k: int = 5, method: str = 'standard', verbose: int = 0)

  Hubness reduction with local scaling.

class `skhubness.reduction.` `MutualProximity`(k: int = 5, method: str = 'normal', verbose: int = 0)

  Hubness reduction with Mutual Proximity.

### Classes

`NoHubnessReduction` | Dummy class to test the library
`LocalScaling`([k, method, verbose]) | Hubness reduction with local scaling.
`MutualProximity`([k, method, verbose]) | Hubness reduction with Mutual Proximity.

### Class Inheritance Diagram

digraph inheritance0b073d742e { rankdir=LR; size="8.0, 12.0"; "LocalScaling" [fontname="Vera Sans, DejaVu Sans, Liberation Sans, Arial, Helvetica, sans",fontsize=10,height=0.25,shape=box,style="setlinewidth(0.5)",tooltip="Hubness reduction with local scaling."]; "MutualProximity" [fontname="Vera Sans, DejaVu Sans, Liberation Sans, Arial, Helvetica, sans",fontsize=10,height=0.25,shape=box,style="setlinewidth(0.5)",tooltip="Hubness reduction with Mutual Proximity."]; "NoHubnessReduction" [fontname="Vera Sans, DejaVu Sans, Liberation Sans, Arial, Helvetica, sans",fontsize=10,height=0.25,shape=box,style="setlinewidth(0.5)",tooltip="Dummy class to test the library"]; }